Error

Enum Error 

pub enum Error {
    OperationTimedOut,
    WriteFailure,
    EndOfWriter,
}
An error that can occur when writing to EEPROM memory.

Variants



OperationTimedOut

The write operation did not complete successfully within the device’s timeout window.

For EEPROM, this means the device did not return a “Ready” status.



WriteFailure

Data written was unable to be verified.



EndOfWriter

The writer has exhausted all of its space.

This indicates that the range provided when creating the writer has been completely exhausted.