Flash64K

Struct Flash64K 

pub struct Flash64K;
A flash device with 64KiB of storage.

This storage type is divided into 16 4KiB sectors. Each sector must be erased before it can be written to. Failing to erase a sector will result in invalid data.

Implementations

Source

impl Flash64K

pub fn reader<'a, 'b, Range>(&'a mut self, range: Range) -> Reader64K<'b>
where Range: RangeBounds<RangedUsize<0, 65535>>, 'a: 'b,

Returns a reader over the given range.

pub fn erase_sectors<Range>(&mut self, sectors: Range) -> Result<(), Error>
where Range: RangeBounds<RangedU8<0, 15>>,

Erases the specified sectors.

This should be called before attempting to write to these sectors. Memory that has already been written to cannot be written to again without first being erased.

pub fn writer<'a, 'b, Range>(&'a mut self, range: Range) -> Writer64K<'b>
where Range: RangeBounds<RangedUsize<0, 65535>>, 'a: 'b,

Returns a writer over the given range.