pub struct Writer64K<'a> { /* private fields */ }Expand description
A writer on a 64KiB flash device.
This type allows writing data on the range specified upon creation.
If the memory being written to has been written to previously without being erased, the writes will not succeed.